pub struct StreamRefProtoConsumer<T>where
T: StreamRefPayload,{ /* private fields */ }Expand description
Consumer-side endpoint that exposes inbound remote elements as a local
Source.
The source sends OnSubscribeHandshake and a cumulative demand ceiling when
it is materialized. It then refills demand at half the configured buffer.
Implementations
Sourceimpl<T> StreamRefProtoConsumer<T>where
T: StreamRefPayload,
impl<T> StreamRefProtoConsumer<T>where
T: StreamRefPayload,
pub fn new(stream_ref_id: StreamRefId, settings: StreamRefSettings) -> Self
pub fn source(&self) -> Source<T, NotUsed>