BroadcastHub

Struct BroadcastHub 

pub struct BroadcastHub;

Implementations

Source

impl BroadcastHub

pub fn sink<T: Clone + Send + 'static>( buffer_size: usize, ) -> Sink<T, BroadcastHubConsumerSource<T>>

Materializes a reusable source for dynamically attaching consumers.

As in Akka, one producer adapts to the slowest active consumer unless callers add their own buffering or dropping stages around the materialized consumer sources.

Unlike Akka, Datum blocks upstream immediately when there are zero consumers instead of pre-buffering up to buffer_size elements.

pub fn sink_starting_after<T: Clone + Send + 'static>( start_after_nr_of_consumers: usize, buffer_size: usize, ) -> Sink<T, BroadcastHubConsumerSource<T>>

Delays upstream consumption until at least start_after_nr_of_consumers consumers attach.