UniqueKillSwitch

Struct UniqueKillSwitch 

pub struct UniqueKillSwitch { /* private fields */ }

Implementations

Source

impl UniqueKillSwitch

pub fn shutdown(&self)

Completes downstream and cancels upstream on the next pull observed by this flow.

In Datum’s pull-based runtime the terminal signal is observed only when downstream issues demand, so tests that expect immediate completion should request one element first.

pub fn abort(&self, error: StreamError)

Fails the stream on the next pull observed by this flow.

In Datum’s pull-based runtime the failure is observed only when downstream issues demand, so tests that expect an immediate error should request one element first.