pub enum KernelBackend {
Auto,
ArrowRust,
Python,
}Expand description
Kernel backend preference for lowerable batch/scalar nodes.
Backend selection is implemented by the M14 kernel rungs. In A1 this is a validated, report-visible planner input only.
Variants
Auto
Let the planner choose the backend for a lowerable node.
ArrowRust
Use Datum’s Rust/Arrow backend.
Python
Use a Python/C++ Arrow backend when that backend is available and selected.