pub struct AsyncBoundaryExecutionConfig {
pub fused: FusedExecutionConfig,
pub buffer_size: usize,
}Expand description
Execution settings for the current graph async-boundary benchmark path.
This path validates a typed-linear graph and uses Ractor-backed async regions with bounded handoff queues to measure real boundary crossing cost.
Fields
fused: FusedExecutionConfigbuffer_size: usizeTrait Implementations
Sourceimpl Clone for AsyncBoundaryExecutionConfig
impl Clone for AsyncBoundaryExecutionConfig
Sourcefn clone(&self) -> AsyncBoundaryExecutionConfig
fn clone(&self) -> AsyncBoundaryExecutionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AsyncBoundaryExecutionConfig
Sourceimpl Debug for AsyncBoundaryExecutionConfig
impl Debug for AsyncBoundaryExecutionConfig
impl Eq for AsyncBoundaryExecutionConfig
Sourceimpl PartialEq for AsyncBoundaryExecutionConfig
impl PartialEq for AsyncBoundaryExecutionConfig
Sourcefn eq(&self, other: &AsyncBoundaryExecutionConfig) -> bool
fn eq(&self, other: &AsyncBoundaryExecutionConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AsyncBoundaryExecutionConfig