pub enum StreamInstrumentationState {
Running,
Draining,
Completed,
Failed,
}Expand description
The externally visible state of one instrumented stream materialization.
Variants
Running
The stream has been materialized and has not reached a terminal state.
Draining
The stream is draining or was dropped before the boundary observed normal completion.
Completed
The boundary observed upstream completion.
Failed
The boundary observed a non-cancellation stream failure.