RestartFlow

Struct RestartFlow 

pub struct RestartFlow;
Akka-style restarting flow wrapper.

Restart flows are lossy across restarts: the element that triggers the wrapped flow failure, and any elements already pulled by that wrapped flow, are dropped. During backoff, downstream demand is held until the central materializer timer fires and the child flow is rematerialized.

Implementations

Source

impl RestartFlow

pub fn with_backoff<In, Out, Mat, F>( settings: RestartSettings, factory: F, ) -> Flow<In, Out>
where In: Send + 'static, Out: Send + 'static, Mat: Send + 'static, F: Fn() -> Flow<In, Out, Mat> + Send + Sync + 'static,

pub fn on_failures_with_backoff<In, Out, Mat, F>( settings: RestartSettings, factory: F, ) -> Flow<In, Out>
where In: Send + 'static, Out: Send + 'static, Mat: Send + 'static, F: Fn() -> Flow<In, Out, Mat> + Send + Sync + 'static,