RestartSink

Struct RestartSink 

pub struct RestartSink;
Akka-style restarting sink wrapper.

Datum’s current sink wrapper accepts factories that materialize StreamCompletion<NotUsed> so the outer sink can wait for each child sink before deciding whether to restart. Like Akka’s restart sink, upstream is backpressured during backoff.

Implementations

Source

impl RestartSink

pub fn with_backoff<In, F>( settings: RestartSettings, factory: F, ) -> Sink<In, StreamCompletion<NotUsed>>
where In: Send + 'static, F: Fn() -> Sink<In, StreamCompletion<NotUsed>> + Send + Sync + 'static,