pub struct RetryFlow;Expand description
Akka-style RetryFlow.withBackoff helpers.
The wrapped flow must be one-in/one-out. Datum validates that at runtime and fails the stream if the wrapped flow emits zero or multiple outputs for a retried element.
Implementations
Sourceimpl RetryFlow
impl RetryFlow
pub fn with_backoff<In, Out, Mat, Decide>( min_backoff: Duration, max_backoff: Duration, random_factor: f64, max_retries: usize, flow: Flow<In, Out, Mat>, decide_retry: Decide, ) -> Flow<In, Out>
pub fn with_backoff_and_context<In, CtxIn, Out, CtxOut, Mat, Decide>( min_backoff: Duration, max_backoff: Duration, random_factor: f64, max_retries: usize, flow: FlowWithContext<In, CtxIn, Out, CtxOut, Mat>, decide_retry: Decide, ) -> FlowWithContext<In, CtxIn, Out, CtxOut>