Module actor

Module actor 

Actor interop APIs backed by Ractor for local execution.

Re-exports

pub use stream_ref_proto::StreamRefFrame;
pub use stream_ref_proto::StreamRefId;
pub use stream_ref_proto::StreamRefMessage;
pub use stream_ref_proto::StreamRefPayload;
pub use stream_ref_proto::StreamRefPayloadBytes;
pub use stream_ref_proto::StreamRefProtoConsumer;
pub use stream_ref_proto::StreamRefProtoEndpoint;
pub use stream_ref_proto::StreamRefProtoProducer;

Modules

stream_ref_proto
Protobuf StreamRefs protocol and transport-agnostic endpoint drivers.

Structs

ActorFlow
Collection of actor-aware stream flows.
ActorPubSub
pg-backed PubSub bridge.
ActorRef
An ActorRef is a strongly-typed wrapper over an ActorCell to provide some syntactic wrapping on the requirement to pass the actor’s message type everywhere.
ActorSink
Collection of actor-backed sink constructors.
ActorSource
Collection of actor-backed source constructors.
ReplyPort
One-shot reply handle supplied to actor ask messages.
ReplySendError
Error returned when an actor tries to answer an ask whose receiver is gone.
SinkRef
A handle that exposes a remote stream as a local Sink.
SourceRef
A handle that exposes a remote stream as a local Source.
StreamRefSettings
Settings used by StreamRefs endpoints.
StreamRefs
Factories for Akka-style stream references.
WatchEvent
Watch failure details used to build the stream failure for ActorFlow::watch.

Enums

ActorSinkBackpressureMessage
Default typed protocol emitted by ActorSink::typed_with_backpressure.
ActorSinkMessage
Default typed protocol emitted by ActorSink::typed.
ActorSourceMessage
Protocol accepted by ActorSource::actor_ref and ActorSource::actor_ref_with_backpressure.
ActorStatus
Status envelope used by ActorFlow::ask_with_status.

Traits

Actor
Actor defines the behavior of an Actor. It specifies the Message type, State type, and all processing logic for the actor
Message
Message type for an actor. Generally an enum which muxes the various types of inner-messages the actor supports

Type Aliases

ActorProcessingErr
Represents an actor’s internal processing error
ActorResult