Actor interop APIs backed by Ractor for local execution.
Re-exports
pub use stream_ref_proto::StreamRefFrame;pub use stream_ref_proto::StreamRefId;pub use stream_ref_proto::StreamRefMessage;pub use stream_ref_proto::StreamRefPayload;pub use stream_ref_proto::StreamRefPayloadBytes;pub use stream_ref_proto::StreamRefProtoConsumer;pub use stream_ref_proto::StreamRefProtoEndpoint;pub use stream_ref_proto::StreamRefProtoProducer;
Modules
- stream_
ref_ proto - Protobuf StreamRefs protocol and transport-agnostic endpoint drivers.
Structs
- Actor
Flow - Collection of actor-aware stream flows.
- Actor
PubSub - pg-backed PubSub bridge.
- Actor
Ref - An ActorRef is a strongly-typed wrapper over an ActorCell to provide some syntactic wrapping on the requirement to pass the actor’s message type everywhere.
- Actor
Sink - Collection of actor-backed sink constructors.
- Actor
Source - Collection of actor-backed source constructors.
- Reply
Port - One-shot reply handle supplied to actor ask messages.
- Reply
Send Error - Error returned when an actor tries to answer an ask whose receiver is gone.
- SinkRef
- A handle that exposes a remote stream as a local
Sink. - Source
Ref - A handle that exposes a remote stream as a local
Source. - Stream
RefSettings - Settings used by
StreamRefsendpoints. - Stream
Refs - Factories for Akka-style stream references.
- Watch
Event - Watch failure details used to build the stream failure for
ActorFlow::watch.
Enums
- Actor
Sink Backpressure Message - Default typed protocol emitted by
ActorSink::typed_with_backpressure. - Actor
Sink Message - Default typed protocol emitted by
ActorSink::typed. - Actor
Source Message - Protocol accepted by
ActorSource::actor_refandActorSource::actor_ref_with_backpressure. - Actor
Status - Status envelope used by
ActorFlow::ask_with_status.
Traits
- Actor
- Actor defines the behavior of an Actor. It specifies the Message type, State type, and all processing logic for the actor
- Message
- Message type for an actor. Generally an enum which muxes the various types of inner-messages the actor supports
Type Aliases
- Actor
Processing Err - Represents an actor’s internal processing error
- Actor
Result