pub struct BroadcastHub;Implementations
Sourceimpl BroadcastHub
impl BroadcastHub
Sourcepub fn sink<T: Clone + Send + 'static>(
buffer_size: usize,
) -> Sink<T, BroadcastHubConsumerSource<T>>
pub fn sink<T: Clone + Send + 'static>( buffer_size: usize, ) -> Sink<T, BroadcastHubConsumerSource<T>>
Materializes a reusable source for dynamically attaching consumers.
As in Akka, one producer adapts to the slowest active consumer unless callers add their own buffering or dropping stages around the materialized consumer sources.
Unlike Akka, Datum blocks upstream immediately when there are zero consumers instead of
pre-buffering up to buffer_size elements.
Sourcepub fn sink_starting_after<T: Clone + Send + 'static>(
start_after_nr_of_consumers: usize,
buffer_size: usize,
) -> Sink<T, BroadcastHubConsumerSource<T>>
pub fn sink_starting_after<T: Clone + Send + 'static>( start_after_nr_of_consumers: usize, buffer_size: usize, ) -> Sink<T, BroadcastHubConsumerSource<T>>
Delays upstream consumption until at least start_after_nr_of_consumers consumers attach.