pub struct RestartFlow;Expand description
Akka-style restarting flow wrapper.
Restart flows are lossy across restarts: the element that triggers the wrapped flow failure, and any elements already pulled by that wrapped flow, are dropped. During backoff, downstream demand is held until the central materializer timer fires and the child flow is rematerialized.
Implementations
Sourceimpl RestartFlow
impl RestartFlow
pub fn with_backoff<In, Out, Mat, F>( settings: RestartSettings, factory: F, ) -> Flow<In, Out>
pub fn on_failures_with_backoff<In, Out, Mat, F>( settings: RestartSettings, factory: F, ) -> Flow<In, Out>